==> pmml-model-1.4.4-sources.jar: org/dmg/pmml/scorecard/Characteristic.java <==

package org.dmg.pmml.scorecard;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "attributes"
})
@XmlRootElement(name = "Characteristic", namespace = "http://www.dmg.org/PMML-4_3")
@Added((org.dmg.pmml.Version.PMML_4_1))
public class Characteristic
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<Characteristic>
{

    @XmlAttribute(name = "name")
    private String name;
    @XmlAttribute(name = "reasonCode")
    private String reasonCode;
    @XmlAttribute(name = "baselineScore")
    private Double baselineScore;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    @XmlElement(name = "Attribute", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    private List<Attribute> attributes;
    private final static long serialVersionUID = 67305483L;

    public Characteristic() {
    }

    public Characteristic(
        @org.jpmml.model.annotations.Property("attributes")
        List<Attribute> attributes) {
        this.attributes = attributes;
    }

    public String getName() {
        return name;
    }

    public Characteristic setName(
        @org.jpmml.model.annotations.Property("name")
        String name) {
        this.name = name;
        return this;
    }

    public String getReasonCode() {
        return reasonCode;
    }

    public Characteristic setReasonCode(
        @org.jpmml.model.annotations.Property("reasonCode")
        String reasonCode) {
        this.reasonCode = reasonCode;
        return this;
    }

    public Double getBaselineScore() {
        return baselineScore;
    }

    public Characteristic setBaselineScore(
        @org.jpmml.model.annotations.Property("baselineScore")
        Double baselineScore) {
        this.baselineScore = baselineScore;
        return this;
    }

    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public List<Attribute> getAttributes() {
        if (attributes == null) {
            attributes = new ArrayList<Attribute>();
        }
        return this.attributes;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public Characteristic addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasAttributes() {
        return ((this.attributes!= null)&&(this.attributes.size()> 0));
    }

    public Characteristic addAttributes(Attribute... attributes) {
        getAttributes().addAll(Arrays.asList(attributes));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasAttributes()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getAttributes());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.4.9-sources.jar: org/dmg/pmml/scorecard/Characteristic.java <==

package org.dmg.pmml.scorecard;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "attributes"
})
@XmlRootElement(name = "Characteristic", namespace = "http://www.dmg.org/PMML-4_3")
@Added((org.dmg.pmml.Version.PMML_4_1))
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "name",
    "reasonCode",
    "baselineScore",
    "extensions",
    "attributes"
})
public class Characteristic
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<Characteristic>
{

    @XmlAttribute(name = "name")
    @JsonProperty("name")
    private String name;
    @XmlAttribute(name = "reasonCode")
    @JsonProperty("reasonCode")
    private String reasonCode;
    @XmlAttribute(name = "baselineScore")
    @JsonProperty("baselineScore")
    private Double baselineScore;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "Attribute", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    @JsonProperty("Attribute")
    private List<Attribute> attributes;
    private final static long serialVersionUID = 67305486L;

    public Characteristic() {
    }

    public Characteristic(
        @org.jpmml.model.annotations.Property("attributes")
        List<Attribute> attributes) {
        this.attributes = attributes;
    }

    public String getName() {
        return name;
    }

    public Characteristic setName(
        @org.jpmml.model.annotations.Property("name")
        String name) {
        this.name = name;
        return this;
    }

    public String getReasonCode() {
        return reasonCode;
    }

    public Characteristic setReasonCode(
        @org.jpmml.model.annotations.Property("reasonCode")
        String reasonCode) {
        this.reasonCode = reasonCode;
        return this;
    }

    public Double getBaselineScore() {
        return baselineScore;
    }

    public Characteristic setBaselineScore(
        @org.jpmml.model.annotations.Property("baselineScore")
        Double baselineScore) {
        this.baselineScore = baselineScore;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public Characteristic addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasAttributes() {
        return ((this.attributes!= null)&&(this.attributes.size()> 0));
    }

    public List<Attribute> getAttributes() {
        if (attributes == null) {
            attributes = new ArrayList<Attribute>();
        }
        return this.attributes;
    }

    public Characteristic addAttributes(Attribute... attributes) {
        getAttributes().addAll(Arrays.asList(attributes));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasAttributes()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getAttributes());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
